paraslash 0.3.0
[paraslash.git] / client.h
index a4d2fe63f473aeb96432dcee1d9b362b77f95f45..3b115fa307b4a93e4b61e5010edf40050945ace2 100644 (file)
--- a/client.h
+++ b/client.h
@@ -1,19 +1,7 @@
 /*
 /*
- * Copyright (C) 1997-2007 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 1997-2008 Andre Noll <maan@systemlinux.org>
  *
  *
- *     This program is free software; you can redistribute it and/or modify
- *     it under the terms of the GNU General Public License as published by
- *     the Free Software Foundation; either version 2 of the License, or
- *     (at your option) any later version.
- *
- *     This program is distributed in the hope that it will be useful,
- *     but WITHOUT ANY WARRANTY; without even the implied warranty of
- *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *     GNU General Public License for more details.
- *
- *     You should have received a copy of the GNU General Public License
- *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ * Licensed under the GPL v2. For licencing details see COPYING.
  */
 
 /** \file client.h common client functions and exported symbols from client_common.c */
  */
 
 /** \file client.h common client functions and exported symbols from client_common.c */
@@ -70,7 +58,7 @@ struct private_client_data {
        /** the client task structure */
        struct task task;
        /** non-zero if task is unregistered */
        /** the client task structure */
        struct task task;
        /** non-zero if task is unregistered */
-       int eof;
+       int error;
        /** the buffer used for handshake and receiving */
        char buf[CLIENT_BUFSIZE];
        /** number of bytes loaded in \p buf */
        /** the buffer used for handshake and receiving */
        char buf[CLIENT_BUFSIZE];
        /** number of bytes loaded in \p buf */
@@ -85,11 +73,9 @@ struct private_client_data {
        char *inbuf;
        /** number of bytes loaded in \p inbuf */
        size_t *in_loaded;
        char *inbuf;
        /** number of bytes loaded in \p inbuf */
        size_t *in_loaded;
-       /** non-zero if input task encountered an eof or an errro condition */
-       int *in_eof;
+       /** Non-zero if input task encountered an eof or an error condition. */
+       int *in_error;
 };
 
 void client_close(struct private_client_data *pcd);
 int client_open(int argc, char *argv[], struct private_client_data **pcd_ptr);
 };
 
 void client_close(struct private_client_data *pcd);
 int client_open(int argc, char *argv[], struct private_client_data **pcd_ptr);
-void client_pre_select(struct sched *s, struct task *t);
-void client_post_select(struct sched *s, struct task *t);